@@ -31,9 +31,7 @@ sscox <- function(formula,type=NULL,data=list(),weights=NULL,subset,
     if ((substr(deparse(resp),1,5)!='Surv(')
         |(substr(deparse(resp),ind.wk,ind.wk)!=')'))
         stop("gss error in sscox: response should be Surv(...)")
-    attach(data)
-    yy <- eval(resp)
-    detach(data)
+    yy <- with(data,eval(resp))
     ## model frame
     term.labels <- attr(term.wk,"term.labels")
     mf[[1]] <- as.name("model.frame")
@@ -280,12 +278,14 @@ sspcox <- function(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,random,bias)
         cv <- (zz$min-cv.shift)/cv.scale
     }
     else {
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
         cv <- zz$min
