@@ -249,12 +249,14 @@ sspdsty <- function(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,bias)
     ## lambda search
     cd <- rep(0,nxi+nnull)
     la <- log.la0
+    mn0 <- log.la0-6
+    mx0 <- log.la0+6
     repeat {
-        mn <- la-1
-        mx <- la+1
-        if (mx>log.la0+6) break
+        mn <- max(la-1,mn0)
+        mx <- min(la+1,mx0)
         zz <- nlm0(cv,c(mn,mx))
-        if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+        if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+            (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
         else la <- zz$est
     }
     ## return
